| Safe Haskell | None |
|---|---|
| Language | GHC2021 |
Codec.CBOR.Cuddle.CBOR.Validator
Documentation
validateCBOR :: ByteString -> Name -> CDDL -> CBORTermResult Source #
data CDDLResult Source #
Constructors
| Valid Rule | The rule was valid |
| ChoiceFail | All alternatives failed |
Fields
| |
| ListExpansionFail | All expansions failed An expansion is: Given a CBOR |
Fields
| |
| MapExpansionFail | All expansions failed An expansion is: Given a CBOR |
Fields
| |
| InvalidControl | The rule was valid but the control failed |
Fields
| |
| InvalidRule Rule | |
| InvalidTagged | A tagged was invalid |
Fields
| |
| UnapplicableRule | The rule we are trying is not applicable to the CBOR term |
Fields
| |
Instances
| Show CDDLResult Source # | |
Defined in Codec.CBOR.Cuddle.CBOR.Validator Methods showsPrec :: Int -> CDDLResult -> ShowS # show :: CDDLResult -> String # showList :: [CDDLResult] -> ShowS # | |
data CBORTermResult Source #
Constructors
| CBORTermResult | |
Fields
| |
Instances
| Show CBORTermResult Source # | |
Defined in Codec.CBOR.Cuddle.CBOR.Validator Methods showsPrec :: Int -> CBORTermResult -> ShowS # show :: CBORTermResult -> String # showList :: [CBORTermResult] -> ShowS # | |
data ValidatorStage Source #
Instances
| IndexMappable CTree MonoReferenced ValidatorStage Source # | |
Defined in Codec.CBOR.Cuddle.CBOR.Validator Methods mapIndex :: CTree MonoReferenced -> CTree ValidatorStage Source # | |
| IndexMappable CTreeRoot MonoReferenced ValidatorStage Source # | |
Defined in Codec.CBOR.Cuddle.CBOR.Validator Methods mapIndex :: CTreeRoot MonoReferenced -> CTreeRoot ValidatorStage Source # | |
| Show (XTerm ValidatorStage) Source # | |
Defined in Codec.CBOR.Cuddle.CBOR.Validator | |
| Show (XXCTree ValidatorStage) Source # | |
Defined in Codec.CBOR.Cuddle.CBOR.Validator | |
| data XTerm ValidatorStage Source # | |
Defined in Codec.CBOR.Cuddle.CBOR.Validator | |
| newtype XXCTree ValidatorStage Source # | |
Defined in Codec.CBOR.Cuddle.CBOR.Validator | |